# TimeSlicedNetMetricsGeneratedReason

Specify the reason why the metrics are generated by the certain order action.  This field is only available to existing Orders customers who already have access to the field.  **Note:** The following Order Metrics have been deprecated. Any new customers who onboard on [Orders](https://knowledgecenter.zuora.com/Billing/Subscriptions/Orders/AA_Overview_of_Orders) or [Orders Harmonization](https://knowledgecenter.zuora.com/Billing/Subscriptions/Orders/Orders_Harmonization/Orders_Harmonization) will not get these metrics. * The Order ELP and Order Item objects  * The \"Generated Reason\" and \"Order Item ID\" fields in the Order MRR, Order TCB, Order TCV, and Order Quantity objects  Existing Orders customers who have these metrics will continue to be supported. 

## Enum

* `INCREASEQUANTITY` (value: `'IncreaseQuantity'`)

* `DECREASEQUANTITY` (value: `'DecreaseQuantity'`)

* `CHANGEPRICE` (value: `'ChangePrice'`)

* `EXTENSION` (value: `'Extension'`)

* `CONTRACTION` (value: `'Contraction'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


